<?php

namespace Modules\Konfirmasibank\Entities;

use Spatie\Activitylog\LogOptions;
use Spatie\Activitylog\Traits\LogsActivity;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use Carbon\Carbon;

class Account extends Model
{
    use HasFactory;

    protected $connection = 'db2';
    protected $table = 'STG_DB.ACCOUNT';
    protected $primaryKey = '@ID';

    //public $incrementing = false;

    protected $fillable = [
    "'CUSTOMER_NO',
    'MNEMONIC'
    'CATEGORY'"
    ];



   public function arrangement()
    {
        return $this->belongsTo(Arrangement::class, 'LINKED_APPL_ID');
    }

    public function getSearchAccount($cif ,$arrAccount, $kodecabang, $startDate){


    // dd($cif ,$arrAccount, $kodecabang, $startDate);
        $uppercaseKodeCabang = Str::upper($kodecabang);
        $data = [];


        if($arrAccount == null){

            $data = DB::connection("db2")->table("STG_DB.ACCOUNT AS AC")
             ->selectRaw('AC.CUSTOMER_NO, MAX(INACTIV_MARKER) as INACTIV_MARKER,AC.ACCOUNT_NUMBER,MAX(AC.BATCH_DATE) AS BATCH_DATE,MAX(AC.CURRENCY)AS CURRENCY, AC.SHORT_TITLE,MAX(AC.OPENING_DATE) AS OPENING_DATE, MAX(AC.WORKING_BALANCE) AS WORKING_BALANCE, MAX(AC.CATEGORY) AS CATEGORY,CT.SHORT_NAME,CP.COMPANY_NAME')
            ->join('STG_DB.CATEGORY AS CT', 'AC.CATEGORY', '=', 'CT.ID')
            ->join('STG_DB.COMPANY AS CP', 'AC.CO_CODE', '=', 'CP.ID')
            ->where('CUSTOMER_NO',$cif)
            ->where('COMPANY_NAME', 'like', "%" .$uppercaseKodeCabang."%")
         //   ->where('INACTIV_MARKER', NULL)
            ->where('AC.BATCH_DATE',$startDate)
            ->whereIn(DB::raw("LEFT(CATEGORY, 3)"),['100','600','660','101'])
            ->groupBy('CUSTOMER_NO','ACCOUNT_NUMBER','SHORT_TITLE','SHORT_NAME','COMPANY_NAME')
            ->limit(100);
        }else{
            $data = DB::connection("db2")->table("STG_DB.ACCOUNT")
            ->select('*')
            ->where('CUSTOMER_NO',$cif)
            ->where('COMPANY_NAME', 'like', "%" .$uppercaseKodeCabang."%")
            ->whereIn('ACCOUNT_NUMBER', $arrAccount)
            ->where('OPENING_DATE', $startDate);
        }

        return $data;
    }

     public function getAccount($cif, $arrAccount,  $startDate){
        // $uppercaseKodeCabang = Str::upper($kodecabang);

          $data = DB::connection("db2")->table("STG_DB.ACCOUNT AS AC")
             ->selectRaw('AC.CUSTOMER_NO, MAX(INACTIV_MARKER) as INACTIV_MARKER,AC.ACCOUNT_NUMBER,MAX(AC.BATCH_DATE) AS BATCH_DATE,MAX(AC.CURRENCY)AS CURRENCY, AC.SHORT_TITLE,MAX(AC.OPENING_DATE) AS OPENING_DATE, MAX(AC.WORKING_BALANCE) AS WORKING_BALANCE, MAX(AC.CATEGORY) AS CATEGORY,CT.SHORT_NAME,CP.COMPANY_NAME')
            ->join('STG_DB.CATEGORY AS CT', 'AC.CATEGORY', '=', 'CT.ID')
            ->join('STG_DB.COMPANY AS CP', 'AC.CO_CODE', '=', 'CP.ID')
            ->where('CUSTOMER_NO',$cif)
            // ->where('COMPANY_NAME', 'like', "%" .$uppercaseKodeCabang."%")
         //   ->where('INACTIV_MARKER', NULL)
            ->where('AC.BATCH_DATE',$startDate)
            ->whereIn('AC.ACCOUNT_NUMBER', $arrAccount)
            //->whereIn(DB::raw("LEFT(CATEGORY, 3)"),['100','600','660','101'])
            ->groupBy('CUSTOMER_NO','ACCOUNT_NUMBER','SHORT_TITLE','SHORT_NAME','COMPANY_NAME')
            ->orderBy('SHORT_NAME', 'ASC')
            ->limit(100);
         return $data;
    }

    public function getCustomer($cus_no){
        $data = [];
        $data =DB::connection("db2")->table("STG_DB.CUSTOMER")->select('CUSTOMER_NO','STREET','RESIDENCE','ADDRESS','SHORT_NAME')->where('CUSTOMER_NO', $cus_no);
        return $data;
    }

    public function getAAaccount($cust, $acc){
        $data = [];
        $data = DB::connection("db2")->table("STG_DB.VW_AA_ACCOUNT")->select('MATURITY_DATE','PRODUCT','TERM')
        //   ->where('CUSTOMER', $cif)
            ->where('CUSTOMER', $cust)
            ->where('LINKED_APPL_ID', $acc)
            ->limit(100);
            return $data;
    }

    public function getPinjaman($cus_no, $dateCore){
       //dd($cus_no, $accNo, $dateCore);

        $data = [];
        $data = DB::connection("db2")->table("STG_DB.VW_AA_ARR")
        ->select('*')
     //   ->join('STG_DB.ACCOUNT AS AC', 'AA.LINKED_APPL_ID', '=', 'AC.ACCOUNT_NUMBER')
        ->where('CUSTOMER',$cus_no)
     //   ->whereIn(DB::raw("LINKED_APPL_ID"),$arr)
       // ->where('ARR_STATUS' , 'CURRENT')
      //  ->orderBy('TERM','DESC');
        ->where('BATCH_DATE', $dateCore)
        ->where('ARR_STATUS','<>', 'CLOSE')
        //->where('LINKED_APPL_ID', $accNo)
      //  ->groupBy('ARRANGEMENT_ID','ACCOUNT_NUMBER','SHORT_TITLE','SHORT_NAME','COMPANY_NAME')
        ->limit(100);

        return $data;

    }

    public function getFixedRate($arrangementId, $startDate){
        $data = [];
        $data = DB::connection("db2")->table("STG_DB.AA_ARR_INTEREST")
        ->select('FIXED_RATE')
        ->where('BATCH_DATE', $startDate)
        ->where(DB::raw("LEFT(ID, 12)"),$arrangementId)
        ->orderBy('ID','DESC');

        return $data;
    }

    public function getMaturityDate($arrangementId,$startDate){
        $data = [];
        $data = DB::connection("db2")->table("STG_DB.AA_ACCOUNT_DETAILS")
        ->select('MATURITY_DATE')
        ->where('ID' ,$arrangementId)
        ->where('BATCH_DATE' ,$startDate)
        ->limit(1)
        ->orderBy('MATURITY_DATE','DESC');

        return $data;
    }

    public function getTermAmount($arrangementId){
        $data = [];
        $data = DB::connection("db2")->table("STG_DB.AA_ARR_TERM_AMOUNT")
        ->select('TERM')
        ->where(DB::raw("LEFT(ID, 12)"),$arrangementId)
        ->orderBy('TERM','DESC')
        ->limit(1);

        return $data;
    }

    public function getSingleAccount($acNo, $date){
        $data = [];
        $data = DB::connection("db2")->table("STG_DB.ACCOUNT")
        ->select('WORKING_BALANCE')
        ->where('ACCOUNT_NUMBER',$acNo)
        ->where('BATCH_DATE',$date)
        ->limit(1)
        ->orderBy('ACCOUNT_NUMBER','DESC');


        return $data;
    }

     public function getCategory($category){
        $data = [];
        $data = DB::connection("db2")->table("STG_DB.CATEGORY")
        ->select('SHORT_NAME')
        ->where('ID',$category);
      //  ->orderBy('TERM','DESC');

        return $data;
    }

     public function getCompany($co_code){
        $data = [];
        $data = DB::connection("db2")->table("STG_DB.COMPANY")
        ->select('COMPANY_NAME')
        ->where('ID',$co_code);
      //  ->orderBy('TERM','DESC');

        return $data;
    }

       public function getLimit($cus_id,$periode){
        $timestamp = strtotime($periode);
        // Format the timestamp into a date format
        $Year = date("Y", $timestamp);
     //   dd($periode);
        $data = [];
        $data =DB::connection("db2")->table("STG_DB.LIMIT AS LM")
        ->select('*')
        ->join('STG_DB.LIMIT_REFERENCE AS LR', 'LM.LIMIT_PRODUCT', '=', 'LR.ID')
        ->join('STG_DB.COMPANY AS CP', 'LM.CO_CODE', '=', 'CP.ID')
        ->join('STG_DB.CATEGORY AS CT', 'LM.LIMIT_PRODUCT', '=', 'CT.ID')
        ->select('LM.ACCOUNT','LM.LIMIT_CURRENCY','LM.APPROVAL_DATE','LM.EXPIRY_DATE','LM.AVAIL_AMT','LM.BATCH_DATE','LM.EXPIRY_DATE','LR.SHORT_NAME','LR.LIMIT_PERCENTAGE','CP.COMPANY_NAME','CT.SHORT_NAME AS ACCOUNT_TYPE')
        ->where(DB::raw("LEFT(LM.@ID, 10)"),$cus_id)
        ->whereYear('LM.BATCH_DATE', $Year)
        ->limit(100);
        //->where('BATCH_DATE', $periode);
       // ->orderBy('LM.@ID','DESC')->get();
        return $data;
       }



}
